@@ -9,7 +9,7 @@ import pylogconf.core
 
 from pymultigit.configs import ConfigDebug, ConfigGrep
 from pymultigit.core import do_count, is_dirty, has_untracked_files, non_synchronized_with_upstream, \
-    do_for_all_projects, do_clean, do_status, do_dirty, do_build, do_pull, do_grep, do_print, do_local_branch, \
+    do_for_all_projects, do_clean, do_status, do_dirty, do_build, do_pull, do_grep, do_local_branch, \
     do_remote_branch, print_projects_that_return_true, do_github_branch
 from pymultigit.static import DESCRIPTION, APP_NAME, VERSION_STR
 
@@ -96,7 +96,7 @@ def clean() -> None:
     description="Show the status of multiple git repositories",
 )
 def status() -> None:
-    do_for_all_projects(do_status, False)
+    print_projects_that_return_true(do_status)
 
 
 @register_endpoint(
@@ -136,7 +136,7 @@ def grep() -> None:
     description="List all projects",
 )
 def list_projects() -> None:
-    do_for_all_projects(do_print, False)
+    print_projects_that_return_true(lambda: (True, ""))
 
 
 @register_main(
